pycocoa.nstypes.at

Package pycocoa :: Module nstypes :: Class at |
[frames] | no frames]

# Class at

              object --+
                       |
    internals._Objectype --+
                           |
           runtime._ObjCBase --+
                               |
            runtime.ObjCInstance --+
                                   |
                               NSStr --+
                                       |
                                      at

Acronym NSStr.

Instance Methods
Inherited from `NSStr`: `__eq__`, `__hash__`, `__ne__`, `__str__` Inherited from `runtime.ObjCInstance`: `__del__`, `__getattr__`, `retained`, `set_ivar` Inherited from `runtime._ObjCBase`: `__repr__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `NSStr`: `__new__`

Properties
Inherited from `NSStr`: `str`, `value` Inherited from `runtime.ObjCInstance`: `Type`, `from_py2NS`, `inPool`, `name`, `objc_class`, `objc_classname`, `objc_description`, `ptr` Inherited from `runtime._ObjCBase`: `description` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`